JsDoc Reference - s

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:33 GMT-0000 (GMT)
HTML template: Codeview

# Namespace s

Settings object which contains customisable information for FixedColumns instance
Defined in: FixedColumns.js.

Namespace Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| s

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | s.columns Number of columns to fix in position
<static> | s.dt DataTables settings objects

Namespace Detail
s
Field Detail
<static> {int} s.columns
Number of columns to fix in position

Default Value:
  1

<static> {object} s.dt
DataTables settings objects

Default Value:
  null